"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const servie_1 = require("servie");
const node_1 = require("servie/dist/body/node");
const zlib_1 = require("zlib");
const _1 = require("./");
describe('get-body', () => {
    describe('text', () => {
        it('should parse body as text', () => __awaiter(this, void 0, void 0, function* () {
            const body = node_1.createBody('hello world');
            const result = yield _1.parse(body.stream(), body.headers.asObject());
            expect(result).toEqual('hello world');
        }));
        it('should support gzip', () => __awaiter(this, void 0, void 0, function* () {
            const body = node_1.createBody('hello world');
            body.headers.set('Content-Encoding', 'gzip');
            const result = yield _1.parse(body.stream().pipe(zlib_1.createGzip()), body.headers.asObject());
            expect(result).toEqual('hello world');
        }));
        it('should support deflate', () => __awaiter(this, void 0, void 0, function* () {
            const body = node_1.createBody('hello world');
            body.headers.set('Content-Encoding', 'deflate');
            const result = yield _1.parse(body.stream().pipe(zlib_1.createDeflate()), body.headers.asObject());
            expect(result).toEqual('hello world');
        }));
    });
    describe('json', () => {
        it('should parse body as json', () => __awaiter(this, void 0, void 0, function* () {
            const body = node_1.createBody({ hello: 'world' });
            const result = yield _1.parse(body.stream(), body.headers.asObject());
            expect(result).toEqual({ hello: 'world' });
        }));
        it('should accept empty strings', () => __awaiter(this, void 0, void 0, function* () {
            const body = node_1.createBody('');
            body.headers.set('Content-Type', 'application/json');
            const result = yield _1.parse(body.stream(), body.headers.asObject());
            expect(result).toEqual({});
        }));
        it('should not accept primitive json', () => __awaiter(this, void 0, void 0, function* () {
            const rawBody = JSON.stringify('test');
            const headers = servie_1.createHeaders({
                'Content-Type': 'application/json',
                'Content-Length': Buffer.byteLength(rawBody)
            });
            const body = new node_1.TextBody({ rawBody, headers });
            expect.assertions(1);
            try {
                yield _1.parse(body.stream(), body.headers.asObject());
            }
            catch (e) {
                expect(e.message).toEqual('Invalid JSON, only supports object and array');
            }
        }));
    });
    describe('form', () => {
        it('should parse body as a form', () => __awaiter(this, void 0, void 0, function* () {
            const rawBody = 'hello=world';
            const headers = servie_1.createHeaders({
                'Content-Type': 'application/x-www-form-urlencoded',
                'Content-Length': Buffer.byteLength(rawBody)
            });
            const body = new node_1.TextBody({ rawBody, headers });
            const result = yield _1.parse(body.stream(), body.headers.asObject());
            expect(result).toEqual({ hello: 'world' });
        }));
    });
    describe('errors', () => {
        it('should error on unknown content types', () => __awaiter(this, void 0, void 0, function* () {
            const headers = servie_1.createHeaders({ 'Content-Type': 'foo/bar' });
            const body = new node_1.TextBody({ rawBody: 'foobar', headers });
            expect.assertions(1);
            try {
                yield _1.parse(body.stream(), body.headers.asObject());
            }
            catch (e) {
                expect(e.message).toEqual('Unsupported content-type: foo/bar');
            }
        }));
        it('should error on no content type', () => __awaiter(this, void 0, void 0, function* () {
            const body = new node_1.EmptyBody({ rawBody: undefined });
            expect.assertions(1);
            try {
                yield _1.parse(body.stream(), body.headers.asObject());
            }
            catch (e) {
                expect(e.message).toEqual('Missing content-type');
            }
        }));
        it('should error on unknown content encoding', () => __awaiter(this, void 0, void 0, function* () {
            const headers = servie_1.createHeaders({
                'Content-Type': 'application/json',
                'Content-Encoding': 'foobar'
            });
            const body = new node_1.TextBody({ rawBody: 'foobar', headers });
            expect.assertions(1);
            try {
                yield _1.parse(body.stream(), body.headers.asObject());
            }
            catch (e) {
                expect(e.message).toEqual('Unsupported content-encoding: foobar');
            }
        }));
    });
});
//# sourceMappingURL=index.spec.js.map